'use client';
'use strict';

var cl = require('clsx/lite');
var react = require('react');
var FieldsetContext = require('./FieldsetContext.js');

/**
 * Handles props and their state for various form-fields in context with Fieldset
 */
const useFormField = (props, prefix) => {
    const fieldset = react.useContext(FieldsetContext.FieldsetContext);
    const randomId = react.useId();
    const id = props.id ?? `${prefix}-${randomId}`;
    const errorId = props.errorId ?? `${prefix}-error-${randomId}`;
    const descriptionId = `${prefix}-description-${randomId}`;
    const size = props.size ?? fieldset?.size ?? 'md';
    const disabled = fieldset?.disabled || props?.disabled;
    const hasError = !disabled && !!(props.error || fieldset?.error);
    return {
        hasError,
        errorId,
        descriptionId,
        size,
        inputProps: {
            id,
            disabled,
            'aria-invalid': hasError ? true : undefined,
            'aria-describedby': cl(props['aria-describedby'], !!props?.description &&
                typeof props?.description === 'string' &&
                descriptionId, hasError && !fieldset?.error && errorId, hasError && !!fieldset?.error && fieldset?.errorId) || undefined,
        },
    };
};

exports.useFormField = useFormField;
