'use client';
'use strict';

var breadcrumbs = require('./breadcrumbs.js');
var breadcrumbsItem = require('./breadcrumbs-item.js');
var breadcrumbsLink = require('./breadcrumbs-link.js');
var breadcrumbsList = require('./breadcrumbs-list.js');

/**
 * `Breadcrumbs` is a component that displays a list of breadcrumbs.
 *
 * @example
 * <Breadcrumbs aria-label='Du er her:'>
 *  <Breadcrumbs.Link href='#' aria-label='Tilbake til Nivå 1'>
 *    Nivå 1
 *  </Breadcrumbs.Link>
 *  <Breadcrumbs.List>
 *    <Breadcrumbs.Item>
 *      <Breadcrumbs.Link href='#'>Nivå 1</Breadcrumbs.Link>
 *    </Breadcrumbs.Item>
 *    <Breadcrumbs.Item>
 *      <Breadcrumbs.Link href='#'>Nivå 2</Breadcrumbs.Link>
 *    </Breadcrumbs.Item>
 *  </Breadcrumbs.List>
 * </Breadcrumbs>
 */
const BreadcrumbsComponent = Object.assign(breadcrumbs.Breadcrumbs, {
    List: breadcrumbsList.BreadcrumbsList,
    Item: breadcrumbsItem.BreadcrumbsItem,
    Link: breadcrumbsLink.BreadcrumbsLink,
});
BreadcrumbsComponent.List.displayName = 'Breadcrumbs.List';
BreadcrumbsComponent.Item.displayName = 'Breadcrumbs.Item';
BreadcrumbsComponent.Link.displayName = 'Breadcrumbs.Link';

exports.BreadcrumbsItem = breadcrumbsItem.BreadcrumbsItem;
exports.BreadcrumbsLink = breadcrumbsLink.BreadcrumbsLink;
exports.BreadcrumbsList = breadcrumbsList.BreadcrumbsList;
exports.Breadcrumbs = BreadcrumbsComponent;
