'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var cl = require('clsx/lite');
var react = require('react');
require('@u-elements/u-details');
var useMergeRefs = require('../../utilities/hooks/use-merge-refs/use-merge-refs.js');

/**
 * Details component, contains `Details.Summary` and `Details.Content` components.
 *
 * @example
 * <Details>
 *  <Details.Summary>Header</Details.Summary>
 *  <Details.Content>Content</Details.Content>
 * </Details>
 */
const Details = react.forwardRef(function Details({ className, open, defaultOpen = false, variant = 'default', onToggle, ...rest }, ref) {
    const detailsRef = react.useRef(null);
    const initialOpen = react.useRef(defaultOpen); // Allow rendering defaultOpen on server, but only render once on client
    const mergedRefs = useMergeRefs.useMergeRefs([detailsRef, ref]);
    const onToggleRef = react.useRef(onToggle); // Using ref to enable access inside useEffect without re-binding event listeners
    const openRef = react.useRef(open);
    onToggleRef.current = onToggle;
    openRef.current = open;
    // Provide onToggle event and controlled state
    react.useEffect(() => {
        const details = detailsRef.current;
        const handleToggle = (event) => {
            if (!details || details?.open === openRef.current)
                return;
            onToggleRef.current?.(event);
            if (openRef.current !== undefined)
                details.open = openRef.current; // Don't update DOM unless controlled state changes
        };
        details?.addEventListener('toggle', handleToggle, true);
        return () => details?.removeEventListener('toggle', handleToggle, true);
    }, []);
    return (jsxRuntime.jsx("u-details", { class: cl('ds-details', className), open: (open ?? initialOpen.current) || undefined, "data-variant": variant, ref: mergedRefs, ...rest }));
});

exports.Details = Details;
