'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var reactSlot = require('@radix-ui/react-slot');
var react = require('react');
var button = require('../button/button.js');
var dialogTriggerContext = require('./dialog-trigger-context.js');

/**
 * DialogTrigger component, used within a Dialog.TriggerContext to open a dialog.
 *
 * @example
 * <Dialog.TriggerContext>
 *   <Dialog.Trigger>Open Dialog</Dialog.Trigger>
 *   <Dialog>
 *     Content
 *   </Dialog>
 * </Dialog.TriggerContext>
 */
const DialogTrigger = react.forwardRef(function DialogTrigger({ asChild, ...rest }, ref) {
    const contextRef = react.useContext(dialogTriggerContext.Context);
    const Component = asChild ? reactSlot.Slot : button.Button;
    const openDialog = () => {
        /* check if element has `data-modal`, it it has, use `showModal` */
        contextRef.current?.getAttribute('data-modal') === 'true'
            ? contextRef.current?.showModal()
            : contextRef.current?.show();
    };
    return (jsxRuntime.jsx(Component, { "aria-haspopup": 'dialog', onClick: openDialog, ref: ref, ...rest }));
});

exports.DialogTrigger = DialogTrigger;
