'use client';
'use strict';

var dropdown = require('./dropdown.js');
var dropdownButton = require('./dropdown-button.js');
var dropdownHeading = require('./dropdown-heading.js');
var dropdownItem = require('./dropdown-item.js');
var dropdownList = require('./dropdown-list.js');
var dropdownTrigger = require('./dropdown-trigger.js');
var dropdownTriggerContext = require('./dropdown-trigger-context.js');

/**
 * Dropdown component, used to display a list of options.
 *
 * @example with TriggerContext
 * <Dropdown.TriggerContext>
 *   <Dropdown.Trigger>Dropdown trigger</Dropdown.Trigger>
 *   <Dropdown placement='bottom-end'>
 *     <Dropdown.Heading>Dropdown</Dropdown.Heading>
 *     <Dropdown.List>
 *       <Dropdown.Item>
 *         <Dropdown.Button>Option</Dropdown.Button>
 *       </Dropdown.Item>
 *     </Dropdown.List>
 *   </Dropdown>
 * </Dropdown.TriggerContext>
 *
 * @example without TriggerContext
 * <Button popovertarget="my-dropdown">Trigger</Button>
 * <Dropdown id="my-dropdown">
 *   <Dropdown.Heading>Heading</Dropdown.Heading>
 *   <Dropdown.List>
 *     <Dropdown.Item>
 *       <Dropdown.Button>Item</Dropdown.Button>
 *     </Dropdown.Item>
 *   </Dropdown.List>
 * </Dropdown>
 */
const DropdownComponent = Object.assign(dropdown.Dropdown, {
    TriggerContext: dropdownTriggerContext.DropdownTriggerContext,
    Heading: dropdownHeading.DropdownHeading,
    List: dropdownList.DropdownList,
    Item: dropdownItem.DropdownItem,
    Button: dropdownButton.DropdownButton,
    Trigger: dropdownTrigger.DropdownTrigger,
});
DropdownComponent.TriggerContext.displayName = 'Dropdown.TriggerContext';
DropdownComponent.List.displayName = 'Dropdown.List';
DropdownComponent.Heading.displayName = 'Dropdown.Heading';
DropdownComponent.Item.displayName = 'Dropdown.Item';
DropdownComponent.Button.displayName = 'Dropdown.Button';
DropdownComponent.Trigger.displayName = 'Dropdown.Trigger';

exports.DropdownButton = dropdownButton.DropdownButton;
exports.DropdownHeading = dropdownHeading.DropdownHeading;
exports.DropdownItem = dropdownItem.DropdownItem;
exports.DropdownList = dropdownList.DropdownList;
exports.DropdownTrigger = dropdownTrigger.DropdownTrigger;
exports.DropdownTriggerContext = dropdownTriggerContext.DropdownTriggerContext;
exports.Dropdown = DropdownComponent;
