'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var heading = require('../heading/heading.js');
var errorSummary = require('./error-summary.js');

/**
 * ErrorSummary heading component, used to display a heading for the error summary.
 *
 * @example
 * <ErrorSummary>
 *   <ErrorSummaryHeading>Heading</ErrorSummaryHeading>
 * </ErrorSummary>
 */
const ErrorSummaryHeading = react.forwardRef(function ErrorSummaryHeading({ className, id, ...rest }, ref) {
    const { headingId, setHeadingId } = react.useContext(errorSummary.ErrorSummaryContext);
    react.useEffect(() => {
        if (id && headingId !== id)
            setHeadingId(id);
    }, [headingId, id, setHeadingId]);
    return jsxRuntime.jsx(heading.Heading, { id: headingId, ref: ref, ...rest });
});

exports.ErrorSummaryHeading = ErrorSummaryHeading;
