'use client';
'use strict';

var errorSummary = require('./error-summary.js');
var errorSummaryHeading = require('./error-summary-heading.js');
var errorSummaryItem = require('./error-summary-item.js');
var errorSummaryLink = require('./error-summary-link.js');
var errorSummaryList = require('./error-summary-list.js');

/**
 * ErrorSummary component, used to display a list of errors.
 *
 * @example
 * <ErrorSummary>
 *   <ErrorSummary.Heading>Heading</ErrorSummary.Heading>
 *   <ErrorSummary.List>
 *     <ErrorSummary.Item>
 *       <ErrorSummary.Link href='#'>Error 1</ErrorSummary.Link>
 *     </ErrorSummary.Item>
 *     <ErrorSummary.Item>
 *       <ErrorSummary.Link href='#'>Error 2</ErrorSummary.Link>
 *     </ErrorSummary.Item>
 *   </ErrorSummary.List>
 * </ErrorSummary>
 */
const ErrorSummaryComponent = Object.assign(errorSummary.ErrorSummary, {
    Heading: errorSummaryHeading.ErrorSummaryHeading,
    Item: errorSummaryItem.ErrorSummaryItem,
    List: errorSummaryList.ErrorSummaryList,
    Link: errorSummaryLink.ErrorSummaryLink,
});
ErrorSummaryComponent.Item.displayName = 'ErrorSummary.Item';
ErrorSummaryComponent.Heading.displayName = 'ErrorSummary.Heading';
ErrorSummaryComponent.List.displayName = 'ErrorSummary.List';
ErrorSummaryComponent.Link.displayName = 'ErrorSummary.Link';

exports.ErrorSummaryHeading = errorSummaryHeading.ErrorSummaryHeading;
exports.ErrorSummaryItem = errorSummaryItem.ErrorSummaryItem;
exports.ErrorSummaryLink = errorSummaryLink.ErrorSummaryLink;
exports.ErrorSummaryList = errorSummaryList.ErrorSummaryList;
exports.ErrorSummary = ErrorSummaryComponent;
