'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var cl = require('clsx/lite');
var react = require('react');

/**
 * FieldAffixes component, used to wrap a form field.
 *
 * @example
 * <Field.Affixes>
 *   <Field.Affix>NOK</Field.Affix>
 *   <Input />
 *   <Field.Affix>pr. mnd.</Field.Affix>
 * </Field.Affixes>
 */
const FieldAffixes = react.forwardRef(function FieldAffixes({ className, ...rest }, ref) {
    return (jsxRuntime.jsx("div", { className: cl('ds-field-affixes', className), ref: ref, ...rest }));
});
/**
 * FieldAffix component, used to wrap a form field.
 * Use together with Field.Affixes.
 *
 * @example
 * <Field.Affixes>
 *   <Field.Affix>NOK</Field.Affix>
 *   <Input />
 *   <Field.Affix>pr. mnd.</Field.Affix>
 * </Field.Affixes>
 */
const FieldAffix = react.forwardRef(function FieldAffix({ className, ...rest }, ref) {
    return (jsxRuntime.jsx("span", { className: cl('ds-field-affix', className), "aria-hidden": 'true', ref: ref, ...rest }));
});

exports.FieldAffix = FieldAffix;
exports.FieldAffixes = FieldAffixes;
