'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var reactSlot = require('@radix-ui/react-slot');
var cl = require('clsx/lite');
var react = require('react');
var fieldObserver = require('./field-observer.js');
var useMergeRefs = require('../../utilities/hooks/use-merge-refs/use-merge-refs.js');

/**
 * Field component, used to wrap a form field.
 *
 * @example
 * <Field>
 *   <Label>Kort beskrivelse</Label>
 *   <Field.Description>Beskrivelse</Field.Description>
 *   <Input />
 *   <ValidationMessage>Feilmelding</ValidationMessage>
 * </Field>
 */
const Field = react.forwardRef(function Field({ className, position, asChild, ...rest }, ref) {
    const Component = asChild ? reactSlot.Slot : 'div';
    const fieldRef = react.useRef(null);
    const mergedRefs = useMergeRefs.useMergeRefs([fieldRef, ref]);
    react.useEffect(() => fieldObserver.fieldObserver(fieldRef.current), []);
    return (jsxRuntime.jsx(Component, { className: cl('ds-field', className), "data-position": position, ref: mergedRefs, ...rest }));
});

exports.Field = Field;
