'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var reactSlot = require('@radix-ui/react-slot');
var cl = require('clsx/lite');
var react = require('react');

const render = (tagName, { asChild, className, ...rest }, ref) => {
    const Component = asChild ? reactSlot.Slot : tagName;
    return jsxRuntime.jsx(Component, { className: cl(`ds-list`, className), ref: ref, ...rest });
};
/**
 * ListUnordered component, used to display a list of items.
 * Renders a native `ul` element.
 *
 * @example
 * <ListUnordered>
 *   <ListItem>Item 1</ListItem>
 *   <ListItem>Item 2</ListItem>
 * </ListUnordered>
 */
const ListUnordered = react.forwardRef(function ListUnordered(props, ref) {
    return render('ul', props, ref);
});
/**
 * ListOrdered component, used to display a list of items.
 * Renders a native `ol` element.
 *
 * @example
 * <ListOrdered>
 *   <ListItem>Item 1</ListItem>
 *   <ListItem>Item 2</ListItem>
 * </ListOrdered>
 */
const ListOrdered = react.forwardRef(function ListOrdered(props, ref) {
    return render('ol', props, ref);
});

exports.ListOrdered = ListOrdered;
exports.ListUnordered = ListUnordered;
