'use client';
'use strict';

var pagination = require('./pagination.js');
var paginationButton = require('./pagination-button.js');
var paginationItem = require('./pagination-item.js');
var paginationList = require('./pagination-list.js');

/**
 * Pagination component, used to navigate through a list of items.
 *
 * @example
 * <Pagination>
 *   <Pagination.List>
 *     <Pagination.Item>
 *       <Pagination.Button aria-label='Forrige side'>Forrige</Pagination.Button>
 *     </Pagination.Item>
 *     <Pagination.Item>
 *       <Pagination.Button aria-label='Side 1'>1</Pagination.Button>
 *     </Pagination.Item>
 *     <Pagination.Item>
 *       <Pagination.Button aria-label='Side 2'>2</Pagination.Button>
 *     </Pagination.Item>
 *   </Pagination.List>
 * </Pagination>
 */
const PaginationComponent = Object.assign(pagination.Pagination, {
    List: paginationList.PaginationList,
    Item: paginationItem.PaginationItem,
    Button: paginationButton.PaginationButton,
});
PaginationComponent.List.displayName = 'Pagination.List';
PaginationComponent.Item.displayName = 'Pagination.Item';
PaginationComponent.Button.displayName = 'Pagination.Button';

exports.PaginationButton = paginationButton.PaginationButton;
exports.PaginationItem = paginationItem.PaginationItem;
exports.PaginationList = paginationList.PaginationList;
exports.Pagination = PaginationComponent;
