'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var reactSlot = require('@radix-ui/react-slot');
var react = require('react');
var button = require('../button/button.js');
var popoverTriggerContext = require('./popover-trigger-context.js');

/**
 * PopoverTrigger component, used to trigger a popover.
 *
 * @example
 * <PopoverTriggerContext>
 *   <PopoverTrigger>Open Popover</PopoverTrigger>
 *   <Popover>
 *     Content
 *   </Popover>
 * </PopoverTriggerContext>
 *
 * @example inline
 * <PopoverTriggerContext>
 *   <Paragraph>
 *    We can use it <PopoverTrigger inline={true}>inline</PopoverTrigger>.
 *   </Paragraph>
 *   <Popover>
 *     Content
 *   </Popover>
 * </PopoverTriggerContext>
 */
const PopoverTrigger = react.forwardRef(function PopoverTrigger({ id, inline, asChild, ...rest }, ref) {
    const { popoverId } = react.useContext(popoverTriggerContext.Context);
    const Component = asChild ? reactSlot.Slot : inline ? 'button' : button.Button;
    const popoverProps = Object.assign({
        [react.version.startsWith('19') ? 'popoverTarget' : 'popovertarget']: popoverId,
        ...(inline
            ? {
                'data-popover': 'inline',
            }
            : {}),
    }, rest);
    return jsxRuntime.jsx(Component, { ref: ref, ...popoverProps });
});

exports.PopoverTrigger = PopoverTrigger;
