'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var button = require('../button/button.js');
var utilities = require('../Combobox/utilities.js');

/**
 * SearchClear component, used to display a clear button when the search input is not empty.
 *
 * @example
 * <Search>
 *   <SearchInput aria-label='Søk' />
 *   <SearchClear />
 * </Search>
 */
const SearchClear = react.forwardRef(function SearchClear({ 'aria-label': label = 'Tøm', onClick, ...rest }, ref) {
    const handleClear = (e) => {
        const target = e.target;
        let input = null;
        if (target instanceof HTMLElement)
            input = target.closest('.ds-search')?.querySelector('input');
        if (!input)
            throw new Error('Input is missing');
        /* narrow type to make TS happy */
        if (!(input instanceof HTMLInputElement))
            throw new Error('Input is not an input element');
        e.preventDefault();
        utilities.setReactInputValue(input, '');
        input.focus();
        onClick?.(e);
    };
    return (jsxRuntime.jsx(button.Button, { ref: ref, variant: 'tertiary', type: 'reset', "aria-label": label, onClick: handleClear, icon: true, ...rest }));
});

exports.SearchClear = SearchClear;
