'use client';
'use strict';

var suggestion = require('./suggestion.js');
var suggestionChips = require('./suggestion-chips.js');
var suggestionClear = require('./suggestion-clear.js');
var suggestionEmpty = require('./suggestion-empty.js');
var suggestionInput = require('./suggestion-input.js');
var suggestionList = require('./suggestion-list.js');
var suggestionOption = require('./suggestion-option.js');

/**
 * A component that provides a suggestion list for an input field.
 *
 * @example
 * <Suggestion>
 *   <Suggestion.Input />
 *   <Suggestion.Clear />
 *   <Suggestion.List>
 *     <Suggestion.Empty>Tomt</Suggestion.Empty>
 *     <Suggestion.Option value='Option 1'>Option 1</Suggestion.Option>
 *     <Suggestion.Option value='Option 2'>Option 2</Suggestion.Option>
 *   </Suggestion.List>
 * </Suggestion>
 */
const EXPERIMENTAL_Suggestion = Object.assign(suggestion.Suggestion, {
    Chips: suggestionChips.SuggestionChips,
    List: suggestionList.SuggestionList,
    Input: suggestionInput.SuggestionInput,
    Empty: suggestionEmpty.SuggestionEmpty,
    Option: suggestionOption.SuggestionOption,
    Clear: suggestionClear.SuggestionClear,
});
EXPERIMENTAL_Suggestion.displayName = 'EXPERIMENTAL_Suggestion';
EXPERIMENTAL_Suggestion.Chips.displayName = 'EXPERIMENTAL_Suggestion.Chips';
EXPERIMENTAL_Suggestion.List.displayName = 'EXPERIMENTAL_Suggestion.List';
EXPERIMENTAL_Suggestion.Input.displayName = 'EXPERIMENTAL_Suggestion.Input';
EXPERIMENTAL_Suggestion.Empty.displayName = 'EXPERIMENTAL_Suggestion.Empty';
EXPERIMENTAL_Suggestion.Option.displayName = 'EXPERIMENTAL_Suggestion.Option';
EXPERIMENTAL_Suggestion.Clear.displayName = 'EXPERIMENTAL_Suggestion.Clear';

exports.EXPERIMENTAL_SuggestionChips = suggestionChips.SuggestionChips;
exports.EXPERIMENTAL_SuggestionClear = suggestionClear.SuggestionClear;
exports.EXPERIMENTAL_SuggestionEmpty = suggestionEmpty.SuggestionEmpty;
exports.EXPERIMENTAL_SuggestionInput = suggestionInput.SuggestionInput;
exports.EXPERIMENTAL_SuggestionList = suggestionList.SuggestionList;
exports.EXPERIMENTAL_SuggestionOption = suggestionOption.SuggestionOption;
exports.EXPERIMENTAL_Suggestion = EXPERIMENTAL_Suggestion;
