'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var input = require('../input/input.js');
var suggestion = require('./suggestion.js');

/**
 * Component that provides an input field for the Suggestion list.
 *
 * Place as a descendant of `Suggestion`
 *
 * @example
 * <Suggestion>
 *   <Suggestion.Input />
 *   <Suggestion.List />
 * </Suggestion>
 */
const SuggestionInput = react.forwardRef(function SuggestionList({ value, onInput, onChange, ...rest }, ref) {
    const { handleFilter } = react.useContext(suggestion.SuggestionContext);
    react.useEffect(handleFilter, [value]); // Filter if controlled value
    if (onChange)
        console.warn('SuggestionInput: Avoid using onChange, as Suggestion controls the Input. Use onValueChange on Suggest instead, or onInput if fetching API results');
    if (value)
        console.warn('SuggestionInput: Avoid using value, as Suggestion controls the Input. Use value on Suggest instead.');
    return (jsxRuntime.jsx(input.Input, { placeholder: '' // We need an empty placeholder for the clear button to be able to show/hide
        , ref: ref, onInput: (event) => {
            onInput?.(event); // Should run first
            handleFilter?.(); // Filter if uncontrolled value
        }, ...rest }));
});

exports.SuggestionInput = SuggestionInput;
