'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
require('@u-elements/u-datalist');
var dom = require('@floating-ui/dom');
var suggestion = require('./suggestion.js');

/**
 * Component that provides a Suggestion list.
 *
 * Place as a descendant of `Suggestion`
 *
 * @example
 * <Suggestion>
 *   <Suggestion.Input />
 *   <Suggestion.List />
 * </Suggestion>
 */
const SuggestionList = react.forwardRef(function SuggestionList({ singular = '%d forslag', plural = '%d forslag', className, id, ...rest }, ref) {
    const { handleFilter, uComboboxRef } = react.useContext(suggestion.SuggestionContext);
    react.useEffect(handleFilter); // Must run on every render
    // Position with floating-ui
    react.useEffect(() => {
        const trigger = uComboboxRef?.current?.control;
        const list = uComboboxRef?.current?.list;
        if (list && trigger) {
            return dom.autoUpdate(trigger, list, () => {
                dom.computePosition(trigger, list, {
                    placement: 'bottom',
                    strategy: 'fixed',
                    middleware: [triggerWidth],
                }).then(({ x, y }) => {
                    list.style.translate = `${x}px calc(${y}px + var(--dsc-suggestion-list-gap))`;
                });
            });
        }
    }, []);
    return (jsxRuntime.jsx("u-datalist", { "data-nofilter": true, "data-sr-singular": singular, "data-sr-plural": plural, class: className, ref: ref, popover: 'manual', ...rest }));
});
const triggerWidth = {
    name: 'TriggerWidth',
    fn(data) {
        const { elements, rects } = data;
        elements.floating.style.width = `${rects.reference.width}px`;
        return data;
    },
};

exports.SuggestionList = SuggestionList;
