'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
require('@u-elements/u-combobox');
var cl = require('clsx/lite');
var index = require('../chip/index.js');
var useMergeRefs = require('../../utilities/hooks/use-merge-refs/use-merge-refs.js');

const SuggestionContext = react.createContext({
    handleFilter: () => undefined,
});
const text = (el) => el.textContent?.trim() || '';
const sanitizeItems = (values = []) => (typeof values === 'string'
    ? [{ label: values, value: values }]
    : values.map((value) => typeof value === 'string'
        ? { label: value, value }
        : {
            label: value.label || value.value || '',
            value: value.value || '',
        })).filter((x) => !!x.label);
const nextItems = (data, prev, multiple) => {
    const item = { label: text(data), value: data.value };
    if (!multiple)
        return data.isConnected ? [] : [item];
    return data.isConnected
        ? sanitizeItems(prev).filter(({ value }) => value !== item.value)
        : [...sanitizeItems(prev), item];
};
const defaultFilter = ({ label, input }) => label.toLowerCase().includes(input.value.trim().toLowerCase());
const deprecate = (from, to) => console.warn(`Suggestion: Using "${from}" is deprecated, please use "${to}" instead.`);
const Suggestion = react.forwardRef(function Suggestion({ children, className, creatable = false, defaultSelected: _defaultSelected, defaultValue, filter = true, multiple = false, name, onBeforeMatch, onSelectedChange: _onSelectedChange, onValueChange, renderSelected = ({ label }) => label, selected: _selected, value, ...rest }, ref) {
    // For backwards compatibility:
    const selected = _selected ?? value;
    const defaultSelected = _defaultSelected ?? defaultValue;
    const onSelectedChange = _onSelectedChange ?? onValueChange;
    if (value)
        deprecate('value', 'selected');
    if (defaultValue)
        deprecate('defaultValue', 'defaultSelected');
    if (onValueChange)
        deprecate('onValueChange', 'onSelectedChange');
    const uComboboxRef = react.useRef(null);
    const genId = react.useId();
    const selectId = rest.id ? `${rest.id}-select` : genId;
    const isControlled = selected !== undefined;
    const mergedRefs = useMergeRefs.useMergeRefs([ref, uComboboxRef]);
    const [isEmpty, setIsEmpty] = react.useState(false);
    const [defaultItems, setDefaultItems] = react.useState(sanitizeItems(defaultSelected));
    const selectedItems = selected ? sanitizeItems(selected) : defaultItems;
    /**
     * Listerners and handling of adding/removing
     */
    react.useEffect(() => {
        const combobox = uComboboxRef.current;
        const beforeChange = (event) => {
            event.preventDefault();
            const multiple = combobox?.multiple;
            const data = event.detail;
            if (isControlled)
                onSelectedChange?.(nextItems(data, selectedItems, multiple));
            else
                setDefaultItems(nextItems(data, selectedItems, multiple));
        };
        combobox?.addEventListener('beforechange', beforeChange);
        return () => combobox?.removeEventListener('beforechange', beforeChange);
    }, [selectedItems, isControlled]);
    // Before match event listener
    react.useEffect(() => {
        const combobox = uComboboxRef.current;
        const beforeMatch = (e) => onBeforeMatch?.(e);
        combobox?.addEventListener('beforematch', beforeMatch);
        return () => combobox?.removeEventListener('beforematch', beforeMatch);
    }, [onBeforeMatch]);
    const handleFilter = react.useCallback(() => {
        const { control: input, options = [] } = uComboboxRef?.current || {};
        const filterFn = filter === true ? defaultFilter : filter;
        let disabled = 0;
        let index = 0;
        for (const option of options)
            if (!option.hasAttribute('data-empty')) {
                if (filterFn && input)
                    option.disabled =
                        !filterFn({
                            index,
                            input,
                            label: option.label,
                            optionElement: option,
                            text: option.text,
                            value: option.value,
                        }) && Boolean(++disabled);
                index++; // Increment index for each <option>
            }
        setIsEmpty(index === disabled);
    }, [filter]);
    return (jsxRuntime.jsx(SuggestionContext.Provider, { value: { isEmpty, handleFilter, uComboboxRef }, children: jsxRuntime.jsxs("u-combobox", { "data-multiple": multiple || undefined, "data-creatable": creatable || undefined, class: cl('ds-suggestion', className), ref: mergedRefs, ...rest, children: [selectedItems.map((item) => (jsxRuntime.jsx(index.Chip.Removable, { value: item.value, asChild: true, children: jsxRuntime.jsx("data", { children: renderSelected(item) }) }, item.value))), children, !!name && (jsxRuntime.jsx("select", { name: name, multiple: true, hidden: true, id: selectId }))] }) }));
});

exports.Suggestion = Suggestion;
exports.SuggestionContext = SuggestionContext;
