'use client';
'use strict';

var table = require('./table.js');
var tableBody = require('./table-body.js');
var tableCell = require('./table-cell.js');
var tableFoot = require('./table-foot.js');
var tableHead = require('./table-head.js');
var tableHeaderCell = require('./table-header-cell.js');
var tableRow = require('./table-row.js');

/**
 * Table component, used to display tabular data. Renders a native HTML table element.
 *
 * @example
 * <Table>
 *   <Table.Head>
 *     <Table.Row>
 *       <Table.HeaderCell>Name</Table.HeaderCell>
 *       <Table.HeaderCell>Age</Table.HeaderCell>
 *     </Table.Row>
 *   </Table.Head>
 *   <Table.Body>
 *     <Table.Row>
 *       <Table.Cell>John</Table.Cell>
 *       <Table.Cell>25</Table.Cell>
 *     </Table.Row>
 *   </Table.Body>
 *   <Table.Foot>
 *     <Table.Row>
 *       <Table.Cell>Total</Table.Cell>
 *       <Table.Cell>2</Table.Cell>
 *     </Table.Row>
 *   </Table.Foot>
 * </Table>
 */
const TableComponent = Object.assign(table.Table, {
    Head: tableHead.TableHead,
    Body: tableBody.TableBody,
    Row: tableRow.TableRow,
    Cell: tableCell.TableCell,
    HeaderCell: tableHeaderCell.TableHeaderCell,
    Foot: tableFoot.TableFoot,
});
TableComponent.displayName = 'Table';
TableComponent.Head.displayName = 'Table.Head';
TableComponent.Body.displayName = 'Table.Body';
TableComponent.Row.displayName = 'Table.Row';
TableComponent.Cell.displayName = 'Table.Cell';
TableComponent.HeaderCell.displayName = 'Table.HeaderCell';
TableComponent.Foot.displayName = 'Table.Foot';

exports.TableBody = tableBody.TableBody;
exports.TableCell = tableCell.TableCell;
exports.TableFoot = tableFoot.TableFoot;
exports.TableHead = tableHead.TableHead;
exports.TableHeaderCell = tableHeaderCell.TableHeaderCell;
exports.TableRow = tableRow.TableRow;
exports.Table = TableComponent;
