'use client';
'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var tabs = require('./tabs.js');
var useMergeRefs = require('../../utilities/hooks/use-merge-refs/use-merge-refs.js');

/**
 * A single content item in a Tabs component.
 *
 * @example
 * <TabsPanel value='1'>content 1</TabsPanel>
 */
const TabsPanel = react.forwardRef(function TabsPanel({ children, value, ...rest }, ref) {
    const { value: tabsValue } = react.useContext(tabs.Context);
    const active = value === tabsValue;
    const [hasTabbableElement, setHasTabbableElement] = react.useState(false);
    const internalRef = react.useRef(null);
    const mergedRef = useMergeRefs.useMergeRefs([ref, internalRef]);
    /* Check if the panel has any tabbable elements */
    react.useEffect(() => {
        if (!internalRef.current)
            return;
        const tabbableElements = internalRef.current.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])');
        setHasTabbableElement(tabbableElements.length > 0);
    }, [children]);
    return (jsxRuntime.jsx(jsxRuntime.Fragment, { children: active && (jsxRuntime.jsx("div", { ref: mergedRef, role: 'tabpanel', tabIndex: hasTabbableElement ? undefined : 0, ...rest, children: children })) }));
});

exports.TabsPanel = TabsPanel;
