'use client';
'use strict';

var react = require('react');
var useIsomorphicLayoutEffect = require('../use-isomorphic-layout-effect/use-isomorphic-layout-effect.js');

// from https://usehooks-ts.com/react-hook/use-media-query
const IS_SERVER = typeof window === 'undefined';
function useMediaQuery(query, { defaultValue = false, initializeWithValue = true, } = {}) {
    const getMatches = (query) => {
        if (IS_SERVER) {
            return defaultValue;
        }
        return window.matchMedia(query).matches;
    };
    const [matches, setMatches] = react.useState(() => {
        if (initializeWithValue) {
            return getMatches(query);
        }
        return defaultValue;
    });
    // Handles the change event of the media query.
    function handleChange() {
        setMatches(getMatches(query));
    }
    useIsomorphicLayoutEffect.useIsomorphicLayoutEffect(() => {
        const matchMedia = window.matchMedia(query);
        // Triggered at the first client-side load and if query changes
        handleChange();
        // Use deprecated `addListener` and `removeListener` to support Safari < 14 (#135)
        if (matchMedia.addListener) {
            matchMedia.addListener(handleChange);
        }
        else {
            matchMedia.addEventListener('change', handleChange);
        }
        return () => {
            if (matchMedia.removeListener) {
                matchMedia.removeListener(handleChange);
            }
            else {
                matchMedia.removeEventListener('change', handleChange);
            }
        };
    }, [query]);
    return matches;
}

exports.useMediaQuery = useMediaQuery;
