'use client';
import { jsx } from 'react/jsx-runtime';
import { Slot } from '@radix-ui/react-slot';
import { forwardRef, useContext } from 'react';
import { Button } from '../button/button.js';
import { Context } from './dialog-trigger-context.js';

/**
 * DialogTrigger component, used within a Dialog.TriggerContext to open a dialog.
 *
 * @example
 * <Dialog.TriggerContext>
 *   <Dialog.Trigger>Open Dialog</Dialog.Trigger>
 *   <Dialog>
 *     Content
 *   </Dialog>
 * </Dialog.TriggerContext>
 */
const DialogTrigger = forwardRef(function DialogTrigger({ asChild, ...rest }, ref) {
    const contextRef = useContext(Context);
    const Component = asChild ? Slot : Button;
    const openDialog = () => {
        /* check if element has `data-modal`, it it has, use `showModal` */
        contextRef.current?.getAttribute('data-modal') === 'true'
            ? contextRef.current?.showModal()
            : contextRef.current?.show();
    };
    return (jsx(Component, { "aria-haspopup": 'dialog', onClick: openDialog, ref: ref, ...rest }));
});

export { DialogTrigger };
