'use client';
import { jsx } from 'react/jsx-runtime';
import { forwardRef, useContext, useEffect } from 'react';
import '@u-elements/u-datalist';
import { autoUpdate, computePosition } from '@floating-ui/dom';
import { SuggestionContext } from './suggestion.js';

/**
 * Component that provides a Suggestion list.
 *
 * Place as a descendant of `Suggestion`
 *
 * @example
 * <Suggestion>
 *   <Suggestion.Input />
 *   <Suggestion.List />
 * </Suggestion>
 */
const SuggestionList = forwardRef(function SuggestionList({ singular = '%d forslag', plural = '%d forslag', className, id, ...rest }, ref) {
    const { handleFilter, uComboboxRef } = useContext(SuggestionContext);
    useEffect(handleFilter); // Must run on every render
    // Position with floating-ui
    useEffect(() => {
        const trigger = uComboboxRef?.current?.control;
        const list = uComboboxRef?.current?.list;
        if (list && trigger) {
            return autoUpdate(trigger, list, () => {
                computePosition(trigger, list, {
                    placement: 'bottom',
                    strategy: 'fixed',
                    middleware: [triggerWidth],
                }).then(({ x, y }) => {
                    list.style.translate = `${x}px calc(${y}px + var(--dsc-suggestion-list-gap))`;
                });
            });
        }
    }, []);
    return (jsx("u-datalist", { "data-nofilter": true, "data-sr-singular": singular, "data-sr-plural": plural, class: className, ref: ref, popover: 'manual', ...rest }));
});
const triggerWidth = {
    name: 'TriggerWidth',
    fn(data) {
        const { elements, rects } = data;
        elements.floating.style.width = `${rects.reference.width}px`;
        return data;
    },
};

export { SuggestionList };
