import { type HTMLAttributes } from 'react';
import type { DefaultProps } from '../../types';
import type { MergeRight } from '../../utilities';
export type BreadcrumbsProps = MergeRight<DefaultProps & HTMLAttributes<HTMLElement>, {
    /**
     * Sets the screen reader label for the Breadcrumbs area
     * @default 'Du er her'
     */
    'aria-label'?: string;
}>;
/**
 * `Breadcrumbs` is a component that displays a list of breadcrumbs.
 *
 * @example
 * <Breadcrumbs aria-label='Du er her:' {...args}>
 *  <Breadcrumbs.Link href='#' aria-label='Tilbake til Nivå 1'>
 *    Nivå 1
 *  </Breadcrumbs.Link>
 *  <Breadcrumbs.List>
 *    <Breadcrumbs.Item>
 *      <Breadcrumbs.Link href='#'>Nivå 1</Breadcrumbs.Link>
 *    </Breadcrumbs.Item>
 *    <Breadcrumbs.Item>
 *      <Breadcrumbs.Link href='#'>Nivå 2</Breadcrumbs.Link>
 *    </Breadcrumbs.Item>
 *  </Breadcrumbs.List>
 * </Breadcrumbs>
 */
export declare const Breadcrumbs: React.ForwardRefExoticComponent<Omit<DefaultProps & HTMLAttributes<HTMLElement>, "aria-label"> & {
    /**
     * Sets the screen reader label for the Breadcrumbs area
     * @default 'Du er her'
     */
    'aria-label'?: string;
} & React.RefAttributes<HTMLElement>>;
//# sourceMappingURL=breadcrumbs.d.ts.map