import type { ButtonHTMLAttributes, InputHTMLAttributes } from 'react';
import type { DefaultProps } from '../../types';
import type { MergeRight } from '../../utilities';
type ChipBaseProps = {
    /**
     * Change the default rendered element for the one passed as a child, merging their props and behavior.
     * @default false
     */
    asChild?: boolean;
};
export type ChipRemovableProps = ChipButtonProps;
export type ChipRadioProps = ChipCheckboxProps;
export type ChipButtonProps = MergeRight<DefaultProps & ButtonHTMLAttributes<HTMLButtonElement>, ChipBaseProps>;
export type ChipCheckboxProps = MergeRight<DefaultProps & Omit<InputHTMLAttributes<HTMLInputElement>, 'type' | 'size'>, ChipBaseProps>;
/**
 * Chip.Button used for interaction
 *
 * @example
 * <Chip.Button>Click me</Chip.Button>
 */
export declare const ChipButton: React.ForwardRefExoticComponent<Omit<DefaultProps & ButtonHTMLAttributes<HTMLButtonElement>, "asChild"> & ChipBaseProps & React.RefAttributes<HTMLButtonElement>>;
/**
 * Chip.Removable used for interaction
 * @example
 * <Chip.Removable>Click to remove me</Chip.Removable>
 */
export declare const ChipRemovable: React.ForwardRefExoticComponent<Omit<DefaultProps & ButtonHTMLAttributes<HTMLButtonElement>, "asChild"> & ChipBaseProps & React.RefAttributes<HTMLButtonElement>>;
/**
 * Chip.Checkbox used for multiselection
 * @example
 * <Chip.Checkbox name="language" value="nynorsk">Nynorsk</Chip.Checkbox>
 * <Chip.Checkbox name="language" value="bokmål">Bokmål</Chip.Checkbox>
 */
export declare const ChipCheckbox: React.ForwardRefExoticComponent<Omit<DefaultProps & Omit<InputHTMLAttributes<HTMLInputElement>, "type" | "size">, "asChild"> & ChipBaseProps & React.RefAttributes<HTMLLabelElement>>;
/**
 * Chip.Radio used for single selection
 * @example
 * <Chip.Radio name="language" value="nynorsk">Nynorsk</Chip.Radio>
 * <Chip.Radio name="language" value="bokmål">Bokmål</Chip.Radio>
 */
export declare const ChipRadio: React.ForwardRefExoticComponent<Omit<DefaultProps & Omit<InputHTMLAttributes<HTMLInputElement>, "type" | "size">, "asChild"> & ChipBaseProps & React.RefAttributes<HTMLLabelElement>>;
export {};
//# sourceMappingURL=chips.d.ts.map