import type { HTMLAttributes, ReactNode } from 'react';
import '@u-elements/u-details';
import type { DefaultProps } from '../../types';
import type { MergeRight } from '../../utilities';
export type DetailsProps = MergeRight<DefaultProps & HTMLAttributes<HTMLDetailsElement>, {
    /**
     * Change the background color of the details.
     *
     * @default 'default'
     */
    variant?: 'default' | 'tinted';
    /**
     * Controls open-state.
     *
     * Using this removes automatic control of open-state
     *
     * @default undefined
     */
    open?: boolean;
    /**
     * Defaults the details to open if not controlled
     * @default false
     */
    defaultOpen?: boolean;
    /**
     * Callback function when Details toggles due to click on summary or find in page-search
     */
    onToggle?: (event: Event) => void;
    /**
     * Content should be one `<Details.Summary>` and `<Details.Content>`
     */
    children?: ReactNode;
}> & ({
    open: boolean;
    onToggle: (event: Event) => void;
} | {
    open?: never;
    onToggle?: (event: Event) => void;
});
/**
 * Details component, contains `Details.Summary` and `Details.Content` components.
 *
 * @example
 * <Details>
 *  <Details.Summary>Header</Details.Summary>
 *  <Details.Content>Content</Details.Content>
 * </Details>
 */
export declare const Details: React.ForwardRefExoticComponent<DetailsProps & React.RefAttributes<HTMLDetailsElement>>;
//# sourceMappingURL=details.d.ts.map