import { type ValidationMessageProps } from '../validation-message/validation-message';
export type FieldCounterProps = {
    /**
     * Label template for when `maxCount` is exceeded.
     * Use `%d` to insert the number of characters.
     *
     * @default '%d tegn for mye'
     */
    over?: string;
    /**
     * Label template for count.
     * Use `%d` to insert the number of characters.
     *
     * @default '%d tegn igjen'
     */
    under?: string;
    /**
     * The maximum allowed characters.
     *
     * @default undefined
     **/
    limit: number;
} & ValidationMessageProps;
/**
 * FieldCounter component, used to display a counter for a form field.
 *
 * @example
 * <Field>
 *   <Input />
 *   <Field.Counter limit={100} under='%d tegn igjen' over='%d tegn for mye' />
 * </Field>
 */
export declare const FieldCounter: React.ForwardRefExoticComponent<{
    /**
     * Label template for when `maxCount` is exceeded.
     * Use `%d` to insert the number of characters.
     *
     * @default '%d tegn for mye'
     */
    over?: string;
    /**
     * Label template for count.
     * Use `%d` to insert the number of characters.
     *
     * @default '%d tegn igjen'
     */
    under?: string;
    /**
     * The maximum allowed characters.
     *
     * @default undefined
     **/
    limit: number;
} & Omit<Omit<import("../../types").DefaultProps, "data-color"> & React.HTMLAttributes<HTMLParagraphElement>, "data-color" | "asChild"> & {
    'data-color'?: import("packages/cli/dist/src/types").SeverityColors;
    asChild?: boolean;
} & React.RefAttributes<HTMLParagraphElement>>;
//# sourceMappingURL=field-counter.d.ts.map