import type { HTMLAttributes } from 'react';
import type { DefaultProps } from '../../types';
export type FieldProps = {
    /**
     * Position of toggle inputs (radio, checkbox, switch) in field
     * @default start
     */
    position?: 'start' | 'end';
    /**
     * Change the default rendered element for the one passed as a child, merging their props and behavior.
     * @default false
     */
    asChild?: boolean;
} & HTMLAttributes<HTMLDivElement> & DefaultProps;
/**
 * Field component, used to wrap a form field.
 *
 * @example
 * <Field>
 *   <Label>Kort beskrivelse</Label>
 *   <Field.Description>Beskrivelse</Field.Description>
 *   <Input />
 *   <ValidationMessage>Feilmelding</ValidationMessage>
 * </Field>
 */
export declare const Field: React.ForwardRefExoticComponent<{
    /**
     * Position of toggle inputs (radio, checkbox, switch) in field
     * @default start
     */
    position?: "start" | "end";
    /**
     * Change the default rendered element for the one passed as a child, merging their props and behavior.
     * @default false
     */
    asChild?: boolean;
} & HTMLAttributes<HTMLDivElement> & DefaultProps & React.RefAttributes<HTMLDivElement>>;
//# sourceMappingURL=field.d.ts.map