import { type HTMLAttributes } from 'react';
import type { DefaultProps } from '../../types';
import { type ButtonProps } from '../button/button';
export type PopoverTriggerProps = ({
    /**
     * Will render the trigger as inline text.
     * @default false
     */
    inline?: true;
    /**
     * Change the default rendered element for the one passed as a child, merging their props and behavior.
     * @default false
     */
    asChild?: boolean;
} & HTMLAttributes<HTMLButtonElement> & DefaultProps) | ({
    /**
     * Will render the trigger as inline text.
     * @default false
     */
    inline?: false;
} & ButtonProps);
/**
 * PopoverTrigger component, used to trigger a popover.
 *
 * @example
 * <PopoverTriggerContext>
 *   <PopoverTrigger>Open Popover</PopoverTrigger>
 *   <Popover>
 *     Content
 *   </Popover>
 * </PopoverTriggerContext>
 *
 * @example inline
 * <PopoverTriggerContext>
 *   <Paragraph>
 *    We can use it <PopoverTrigger inline={true}>inline</PopoverTrigger>.
 *   </Paragraph>
 *   <Popover>
 *     Content
 *   </Popover>
 * </PopoverTriggerContext>
 */
export declare const PopoverTrigger: React.ForwardRefExoticComponent<PopoverTriggerProps & React.RefAttributes<HTMLButtonElement>>;
//# sourceMappingURL=popover-trigger.d.ts.map