import { type ReactNode } from 'react';
import type { MergeRight } from '../../utilities';
import { type ButtonProps } from '../button/button';
export type SearchButtonProps = MergeRight<ButtonProps, {
    /**
     * Variant of the button
     * @default 'primary'
     */
    variant?: 'primary' | 'secondary';
    /**
     * Children of the button
     * @default 'Søk'
     */
    children?: ReactNode;
}>;
/**
 * SearchButton component, used to display a search button within a Search component.
 *
 * @example
 * <Search>
 *   <SearchInput aria-label='Søk' />
 *   <SearchButton>Søk</SearchButton>
 * </Search>
 */
export declare const SearchButton: React.ForwardRefExoticComponent<Omit<import("../../types").DefaultProps & React.ButtonHTMLAttributes<HTMLButtonElement>, "type" | "data-color" | "variant" | "icon" | "loading" | "asChild"> & {
    variant?: "primary" | "secondary" | "tertiary";
    'data-color'?: import("packages/cli/dist/src/types").Color | Extract<import("packages/cli/dist/src/types").SeverityColors, "danger">;
    icon?: boolean;
    loading?: boolean | ReactNode;
    asChild?: boolean;
    type?: React.ButtonHTMLAttributes<HTMLButtonElement>["type"];
} & React.RefAttributes<HTMLButtonElement>>;
//# sourceMappingURL=search-button.d.ts.map