import { type AnchorHTMLAttributes, type ReactNode } from 'react';
import type { DefaultProps } from '../../types';
import type { MergeRight } from '../../utilities';
export type SkipLinkProps = MergeRight<DefaultProps & AnchorHTMLAttributes<HTMLAnchorElement>, {
    /**
     * The content to display inside the skiplink.
     */
    children: ReactNode;
    /**
     * Href of an element in the DOM the skiplink should skip to. E.g #main-content
     */
    href: string;
}>;
/**
 * SkipLink component, used to display a skip link within the page.
 * Place it at the top of the page to allow users to skip to the main content.
 *
 * @example
 * <SkipLink href='#main-content'>Skip to main content</SkipLink>
 */
export declare const SkipLink: React.ForwardRefExoticComponent<Omit<DefaultProps & AnchorHTMLAttributes<HTMLAnchorElement>, "children" | "href"> & {
    /**
     * The content to display inside the skiplink.
     */
    children: ReactNode;
    /**
     * Href of an element in the DOM the skiplink should skip to. E.g #main-content
     */
    href: string;
} & React.RefAttributes<HTMLAnchorElement>>;
//# sourceMappingURL=skip-link.d.ts.map