import { type HTMLAttributes, type ReactNode } from 'react';
import '@u-elements/u-combobox';
import type { UHTMLComboboxElement } from '@u-elements/u-combobox';
export type SuggestionSelected = Array<string | Partial<Item>> | string;
type Item = {
    label: string;
    value: string;
};
type EventBeforeMatch = Omit<CustomEvent<HTMLOptionElement | undefined>, 'currentTarget'> & {
    currentTarget: UHTMLComboboxElement;
};
type Filter = (args: {
    /**
     * Index of the `option`
     */
    index: number;
    /**
     * Label content of the `option`
     */
    label: string;
    /**
     * Text content of the `option`
     */
    text: string;
    /**
     * Value of the `option`
     */
    value: string;
    /**
     * The DOM element of the `option`
     */
    optionElement: HTMLOptionElement;
    /**
     * The DOM element of the `input`
     */
    input: HTMLInputElement;
}) => boolean;
type SuggestionContextType = {
    handleFilter: (input?: HTMLInputElement | null) => void;
    isEmpty?: boolean;
    uComboboxRef?: React.RefObject<UHTMLComboboxElement | null>;
};
export declare const SuggestionContext: React.Context<SuggestionContextType>;
export type SuggestionProps = {
    /**
     * Filter options; boolean or a custom callback.
     *
     * See {@link Filter} for the callback signature.
     *
     * @default true
     */
    filter?: boolean | Filter;
    /**
     * Allows the user to create new items
     *
     * @default false
     */
    creatable?: boolean;
    /**
     * Allows the user to select multiple items
     *
     * @default false
     */
    multiple?: boolean;
    /**
     * The selected items of the Suggestion.
     *
     * If `label` and `value` is the same, you can use `string[]`.
     *
     * If `label` and `value` is different, you must use `{ value: string; label: string}[]`.
     *
     * Using this makes the component controlled and it must be used in combination with `onSelectedChange`.
     */
    selected?: SuggestionSelected;
    /**
     * @deprecated Use `selected` instead
     */
    value?: SuggestionSelected;
    /**
     * Default selected items when uncontrolled
     */
    defaultSelected?: SuggestionSelected;
    /**
     * @deprecated Use `defaultSelected` instead
     */
    defaultValue?: SuggestionSelected;
    /**
     * Callback when selected items changes
     */
    onSelectedChange?: (value: Item[]) => void;
    /**
     * @deprecated Use `onSelectedChange` instead
     */
    onValueChange?: (value: Item[]) => void;
    /**
     * Callback when matching input value against options
     */
    onBeforeMatch?: (event: EventBeforeMatch) => void;
    /**
     * The name of the associated form control
     *
     * @default undefined
     */
    name?: string;
    /**
     * Change how the selected options are rendered inside the `Chip`.
     *
     * @default ({ label }) => label
     */
    renderSelected?: (args: {
        label: string;
        value: string;
    }) => ReactNode;
} & HTMLAttributes<UHTMLComboboxElement>;
export declare const Suggestion: React.ForwardRefExoticComponent<{
    /**
     * Filter options; boolean or a custom callback.
     *
     * See {@link Filter} for the callback signature.
     *
     * @default true
     */
    filter?: boolean | Filter;
    /**
     * Allows the user to create new items
     *
     * @default false
     */
    creatable?: boolean;
    /**
     * Allows the user to select multiple items
     *
     * @default false
     */
    multiple?: boolean;
    /**
     * The selected items of the Suggestion.
     *
     * If `label` and `value` is the same, you can use `string[]`.
     *
     * If `label` and `value` is different, you must use `{ value: string; label: string}[]`.
     *
     * Using this makes the component controlled and it must be used in combination with `onSelectedChange`.
     */
    selected?: SuggestionSelected;
    /**
     * @deprecated Use `selected` instead
     */
    value?: SuggestionSelected;
    /**
     * Default selected items when uncontrolled
     */
    defaultSelected?: SuggestionSelected;
    /**
     * @deprecated Use `defaultSelected` instead
     */
    defaultValue?: SuggestionSelected;
    /**
     * Callback when selected items changes
     */
    onSelectedChange?: (value: Item[]) => void;
    /**
     * @deprecated Use `onSelectedChange` instead
     */
    onValueChange?: (value: Item[]) => void;
    /**
     * Callback when matching input value against options
     */
    onBeforeMatch?: (event: EventBeforeMatch) => void;
    /**
     * The name of the associated form control
     *
     * @default undefined
     */
    name?: string;
    /**
     * Change how the selected options are rendered inside the `Chip`.
     *
     * @default ({ label }) => label
     */
    renderSelected?: (args: {
        label: string;
        value: string;
    }) => ReactNode;
} & HTMLAttributes<UHTMLComboboxElement> & React.RefAttributes<UHTMLComboboxElement>>;
export {};
//# sourceMappingURL=suggestion.d.ts.map