import type { HTMLAttributes } from 'react';
import type { DefaultProps } from '../../types';
import type { MergeRight } from '../../utilities';
export type TabsProps = MergeRight<DefaultProps & Omit<HTMLAttributes<HTMLDivElement>, 'onChange' | 'value'>, {
    /**
     * Controlled state for `Tabs` component
     * @default undefined
     */
    value?: string;
    /**
     * Default selected tab value
     * @default undefined
     */
    defaultValue?: string;
    /**
     * Callback with selected `TabItem` `value`
     * @default undefined
     */
    onChange?: (value: string) => void;
}>;
export type ContextProps = {
    value?: string;
    defaultValue?: string;
    onChange?: (value: string) => void;
};
export declare const Context: React.Context<ContextProps>;
/**
 * Display a group of tabs that can be toggled between.
 *
 * @example
 * <Tabs onChange={(value) => console.log(value)}>
 *   <Tabs.List>
 *     <Tabs.Tab value='1'>Tab 1</Tabs.Tab>
 *     <Tabs.Tab value='2'>Tab 2</Tabs.Tab>
 *     <Tabs.Tab value='3'>Tab 3</Tabs.Tab>
 *   </Tabs.List>
 *   <Tabs.Panel value='1'>content 1</Tabs.Panel>
 *   <Tabs.Panel value='2'>content 2</Tabs.Panel>
 *   <Tabs.Panel value='3'>content 3</Tabs.Panel>
 * </Tabs>
 */
export declare const Tabs: React.ForwardRefExoticComponent<Omit<DefaultProps & Omit<HTMLAttributes<HTMLDivElement>, "value" | "onChange">, "defaultValue" | "value" | "onChange"> & {
    /**
     * Controlled state for `Tabs` component
     * @default undefined
     */
    value?: string;
    /**
     * Default selected tab value
     * @default undefined
     */
    defaultValue?: string;
    /**
     * Callback with selected `TabItem` `value`
     * @default undefined
     */
    onChange?: (value: string) => void;
} & React.RefAttributes<HTMLDivElement>>;
//# sourceMappingURL=tabs.d.ts.map